@@ -25,13 +25,14 @@
 #include <glib.h>
 #include <gio/gio.h>
 
+#include "terminal-app.h"
 #include "terminal-enums.h"
 #include "terminal-intl.h"
 #include "profile-editor.h"
 #include "terminal-schemas.h"
 #include "terminal-type-builtins.h"
 #include "terminal-util.h"
-#include "terminal-profile-utils.h"
+#include "terminal-profiles-list.h"
 
 typedef struct _TerminalColorScheme TerminalColorScheme;
 
@@ -459,7 +460,7 @@ editor_response_cb (GtkWidget *editor,
 {  
   if (response == GTK_RESPONSE_HELP)
     {
-      terminal_util_show_help ("gnome-terminal-prefs", GTK_WINDOW (editor));
+      terminal_util_show_help ("profile", GTK_WINDOW (editor));
       return;
     }
 
@@ -548,39 +549,6 @@ scroll_event_cb (GtkWidget      *widget,
   return FALSE;
 }
 
-static void
-terminal_profile_editor_focus_widget (GtkWidget *editor,
-                                      const char *widget_name)
-{
-  GtkBuilder *builder;
-  GtkWidget *widget, *page, *page_parent;
-
-  if (widget_name == NULL)
-    return;
-
-  builder = g_object_get_data (G_OBJECT (editor), "builder");
-  widget = GTK_WIDGET (gtk_builder_get_object (builder, widget_name));
-  if (widget == NULL)
-    return;
-
-  page = widget;
-  while (page != NULL &&
-         (page_parent = gtk_widget_get_parent (page)) != NULL &&
-         !GTK_IS_NOTEBOOK (page_parent))
-    page = page_parent;
-
-  page_parent = gtk_widget_get_parent (page);
-  if (page != NULL && GTK_IS_NOTEBOOK (page_parent)) {
-    GtkNotebook *notebook;
-
-    notebook = GTK_NOTEBOOK (page_parent);
-    gtk_notebook_set_current_page (notebook, gtk_notebook_page_num (notebook, page));
-  }
-
-  if (gtk_widget_is_sensitive (widget))
-    gtk_widget_grab_focus (widget);
-}
-
 static gboolean
 string_to_window_title (GValue *value,
                         GVariant *variant,
@@ -707,6 +675,7 @@ terminal_profile_edit (GSettings  *profile,
                        GtkWindow  *transient_parent,
                        const char *widget_name)
 {
+  TerminalSettingsList *profiles_list;
   GtkBuilder *builder;
   GError *error = NULL;
   GtkWidget *editor, *w;
@@ -716,7 +685,7 @@ terminal_profile_edit (GSettings  *profile,
   editor = g_object_get_data (G_OBJECT (profile), "editor-window");
   if (editor)
     {
-      terminal_profile_editor_focus_widget (editor, widget_name);
+      terminal_util_dialog_focus_widget (editor, widget_name);
 
       gtk_window_set_transient_for (GTK_WINDOW (editor),
                                     GTK_WINDOW (transient_parent));
@@ -724,6 +693,8 @@ terminal_profile_edit (GSettings  *profile,
       return;
     }
 
+  profiles_list = terminal_app_get_profiles_list (terminal_app_get ());
+
   builder = gtk_builder_new ();
   gtk_builder_add_from_resource (builder, "/org/gnome/terminal/ui/profile-preferences.ui", &error);
   g_assert_no_error (error);
@@ -749,7 +720,7 @@ terminal_profile_edit (GSettings  *profile,
   gtk_widget_add_events (w, GDK_BUTTON_PRESS_MASK | GDK_SCROLL_MASK);
   g_signal_connect (w, "scroll-event", G_CALLBACK (scroll_event_cb), NULL);
 
-  uuid = terminal_profile_util_get_profile_uuid (profile);
+  uuid = terminal_settings_list_dup_uuid_from_child (profiles_list, profile);
   gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (builder, "profile-uuid")),
                       uuid);
   g_free (uuid);
@@ -1023,7 +994,7 @@ terminal_profile_edit (GSettings  *profile,
 
   terminal_util_bind_mnemonic_label_sensitivity (editor);
 
-  terminal_profile_editor_focus_widget (editor, widget_name);
+  terminal_util_dialog_focus_widget (editor, widget_name);
 
   gtk_window_set_transient_for (GTK_WINDOW (editor),
                                 GTK_WINDOW (transient_parent));
