@@ -56,9 +56,13 @@ char *terminal_util_concat_uris (char **uris,
 char *terminal_util_get_licence_text (void);
 
 void terminal_util_load_builder_resource (const char *path,
+                                          const char *main_object_name,
                                           const char *object_name,
                                           ...);
 
+void terminal_util_dialog_focus_widget (GtkWidget *dialog,
+                                        const char *widget_name);
+
 gboolean terminal_util_dialog_response_on_delete (GtkWindow *widget);
 
 void terminal_util_key_file_set_string_escape    (GKeyFile *key_file,
